<?php
/*
Plugin Name: Publish2
Plugin URI: http://www.publish2.com/
Description: Brings link journalism from <a href="http://www.publish2.com/">Publish2</a> to your WordPress-powered blog or website. <a href="/wp-admin/profile.php">Enable Link Assist</a> to quickly add previously-saved links as you write a post, or display links with a <a href="/wp-admin/widgets.php">sidebar widget</a>, the ability to <a href="/wp-admin/edit-pages.php">append links at the bottom of any page</a>, or a flexible PHP function.
Version: 1.4.1
Author: Daniel Bachhuber
Author URI: http://www.publish2.com/journalists/daniel-bachhuber/
*/

// Default settings
$p2_defaults = array(
	'feedlink' => 'http://www.publish2.com/recent/',
	'link_count' => 5,
	'publication_name' => true,
	'publication_date' => true,
	'journalist_full_name' => true,
	'description' => true,
	'tags' => true,
	'link_format' => null,
	'settings_source' => null,
	'display_list' => false
);

$testoptions = get_option('publish2_settings');

if ($testoptions == null) { update_option('publish2_settings', $p2_defaults); }

require_once('php/p2functions.php');

// WordPress hook to add some custom JS to the header of the WordPress admin
function publish2_js_admin_header() {
	
	// use JavaScript SACK library for Ajax
	wp_print_scripts( array( 'sack' ));

	// A touch of extra Javascript and CSS
?>
	
<link rel='stylesheet' href='/wp-content/plugins/publish2/css/linkassist.css' type='text/css' media='all' />
<!--[if lte IE 6]>
<link rel='stylesheet' href='/wp-content/plugins/publish2/css/ie.css' type='text/css' media='all' />
<![endif]-->
<script type='text/javascript' src='/wp-content/plugins/publish2/js/linkassist.js'></script>
<script type='text/javascript' src='/wp-content/plugins/publish2/js/json2.js'></script>
<script type="text/javascript">
//<![CDATA[
	// Allows the user to flip between normal and advanced display options on the widget
	function p2_display_options(sel) {
		
		var opt = sel.options[sel.selectedIndex].value;
		if(opt==1) {
			jQuery(".normal_options").hide();
			jQuery(".advanced_options").show();
		} else {
			jQuery(".advanced_options").hide();
			jQuery(".normal_options").show();
		}

	}
//]]>
</script>

<?php
}

// Link Assist box on the Post page allows the user to quickly add link journalism to content
function p2_post_linkassist_box() {
	
	// Get the user's information so that we can pull their P2 settings from the database
	global $post;
	$post_id = $post->ID;
	$current_user = wp_get_current_user();
	$user_id = $current_user->ID;
	
	$defaults = get_option('publish2_widget_settings');
	
	// Get the feedlink associated with the user. If that doesn't work, defer to default for the instance, and then the most recent newswire
	$feedlink = get_usermeta($user_id, 'publish2_url');
	if ($feedlink == null || $feedlink == 'http://' || $feedlink == '') {
		$feedlink = $defaults['feedlink'];
		if ($feedlink == null || $feedlink == 'http://' || $feedlink == '') {
				$feedlink = 'http://www.publish2.com/recent';
		}
	}
	
	$linkassist_publication = get_usermeta($user_id, 'p2_linkassist_publication');
	$linkassist_date = get_usermeta($user_id, 'p2_linkassist_date');
	$linkassist_journalist = get_usermeta($user_id, 'p2_linkassist_journalist');
	$linkassist_comment = get_usermeta($user_id, 'p2_linkassist_comment');
	$linkassist_tags = get_usermeta($user_id, 'p2_linkassist_tags');
	$video_width = get_usermeta($user_id, 'p2_video_width');
	
	// Check to see whether the settings have been used before. If not, fill in with the defaults from the widget
	if ($linkassist_publication == null) {
		$linkassist_publication = $defaults['publication_name'];
		if ($linkassist_publication == 1) { $linkassist_publication = 'on'; }
	}
	if ($linkassist_date == null) {
		$linkassist_date = $defaults['publication_date'];
		if ($linkassist_date == 1) { $linkassist_date = 'on'; }
	}
	if ($linkassist_journalist == null) {
		$linkassist_journalist = $defaults['journalist_full_name'];
		if ($linkassist_journalist == 1) { $linkassist_journalist = 'on'; }
	}
	if ($linkassist_comment == null) {
		$linkassist_comment = $defaults['description'];
		if ($linkassist_comment == 1) { $linkassist_comment = 'on'; }
	}
	if ($linkassist_tags == null) {
		$linkassist_tags = $defaults['tags'];
		if ($linkassist_tags == 1) { $linkassist_tags = 'on'; }
	}
	if ($video_width == null) { $video_width = 425; }
	
	echo '<div id="p2-link_assist-topnav">';
		
	echo '<div id="p2-link_assist-navwrap">';
		
		echo '<div id="p2-links_header">';
			
		echo '<span id="p2_links_title">Link journalism at your fingertips</span> ';
		echo '<a href="javascript:void(0)" onclick="p2_url_source(1);return false;" id="p2-source-edit">Edit</a>';
			
		echo '</div>';
			
		echo '<div id="p2-source-option" style="display:none;">';
			
			echo 'URL: ';
			echo '<input type="text" id="publish2-feedlink" name="publish2-feedlink" size="17" value="' . $feedlink . '" />';
			echo '<a href="javascript:void(0)" onclick="p2_url_source(2);return false;" class="button">OK</a> ';
			echo '<a href="javascript:void(0)" onclick="p2_url_source(3);return false;">Cancel</a>';
			
		echo '</div>';
			
	echo '</div>';
		
	echo '</div>';
	
	echo '<div id="p2-link_assist-inside">';
	
	?>

<input type="hidden" name="publish2-nonce" id="publish2-nonce" value="<?php echo wp_create_nonce('publish2-nonce'); ?>" />

<div id="p2-pagination"></div>

<div id="p2-network_nav"></div>
	
<div id="publish2-link_assist-links">
	
	<div id="p2-welcome_splash">
		
		<img src="/wp-content/plugins/publish2/img/publish2_h250.gif" width="250" height="70" style="padding-top:15px;">
		
	</div>
	
</div>

<div id="p2-link_count"></div>
	
<script type="text/javascript">
	// Loads the list of links when the page has completely loaded
	var feedlink = "<?php echo $feedlink; ?>";
	jQuery(document).ready(function(){
		p2_listlinks(feedlink, null, null);
	});
</script>
	
	<?php
	
	echo '</div>';
	
	echo '<div id="p2-link_assist-bottomnav">';
	
		echo '<div id="p2-link_assist-navwrap">';
			
			$p2_filter_action = "p2_linksnav('filter');return false;";
			echo 'Tag: <input type="text" id="p2-filter_tag" name="p2-filter_tag" value="" size="18" /> ';
			echo '<a href="javascript:void(0);" onclick="' . $p2_filter_action . '"class="button">Filter</a> ';
			
			$p2_reset_action = "p2_linksnav('reset');return false;";
			echo '<a href="javascript:void(0);" onclick="' . $p2_reset_action . '"class="resetbutton" id="p2-link_assist-reset"><img src="/wp-content/plugins/publish2/img/loading_static-red.gif" /></a>';
	
		echo '</div>';
	
	echo '</div>';
	
	echo '<div id="p2-temp_settings" style="display:none;"></div>';
	echo '<div id="p2-user_settings" style="display:none;">';
	echo '<span id="p2-linkassist_publication">' . $linkassist_publication . '</span>';
	echo '<span id="p2-linkassist_date">' . $linkassist_date . '</span>';
	echo '<span id="p2-linkassist_journalist">' . $linkassist_journalist . '</span>';
	echo '<span id="p2-linkassist_comment">' . $linkassist_comment . '</span>';
	echo '<span id="p2-linkassist_tags">' . $linkassist_tags . '</span>';
	echo '<span id="p2-video_width">' . $video_width . '</span>';
	echo '</div>';
	
}

// WordPress hook to add the settings box to the post edit
function p2_add_post_linkassist_box() {
	
	// Assess whether the current user has Link Assist enabled or not
	$current_user = wp_get_current_user();
	$user_id = $current_user->ID;
	$linkassist = get_usermeta($user_id, 'publish2_linkassist');
	
	// If it's possible to and the user wants it, add Link Assist to edit post page
	if (function_exists('add_meta_box') && $linkassist != 'off') {
		add_meta_box('publish2_linkassist', 'Publish2 Link Assist', 'p2_post_linkassist_box', 'post', 'side', 'high');
	} 
}

// WordPress function that places a settings box at the bottom of an edit page
function p2_save_post_meta_box($post_id) {

	$current_user = wp_get_current_user();
	$user_id = $current_user->ID;

	if ( !wp_verify_nonce( $_POST['publish2-nonce'], 'publish2-nonce')) {
		return $post_id;  
	}
        
	if ( 'post' == $_POST['post_type'] ) {	
		if (!current_user_can( 'edit_post', $post_id ))
			return $post_id;  
	}

	// Save the currently used feedlink back to the user's profile
	$feedlink = $_POST['publish2-feedlink'];
	$feedlink = p2_clean_url($feedlink);
	update_usermeta($user_id, 'publish2_url', $feedlink);
		
}

// WordPress hook to add the settings box to the post edit
function p2_add_post_meta_box() {
	if (function_exists('add_meta_box')) {
		add_meta_box('publish2_link-assist', 'Publish2 Link Assist', 'p2_post_meta_box', 'post', 'normal', 'high');
	} 
}


// WordPress function to add a metabox to the create a new post or page page
function p2_page_meta_box() {
	global $post;
	$post_id = $post->ID;
	
	//Get the default settings from the settings page if they aren't yet established with the page
	$defaults = get_option('publish2_settings');

	$link_page = get_post_meta($post_id, '_link_page');
	if ($link_page == null) { $link_page[0] = false; }
	
	$feedlink = get_post_meta($post_id, '_feedlink');
	if ($feedlink == null) { $feedlink[0] = $defaults['feedlink']; }
	
	$link_count = get_post_meta($post_id, '_link_count');
	if ($link_count == null) { $link_count[0] = 5; }
		
	$advanced_options = get_post_meta($post_id, '_advanced_options');
	if ($advanced_options == null) { $advanced_options[0] = 0; }
	
	$publication_name = get_post_meta($post_id, '_publication_name');
	if ($publication_name == null) { $publication_name[0] = true; }
	
	$publication_date = get_post_meta($post_id, '_publication_date');
	if ($publication_date == null) { $publication_date[0] = true; }
		
	$journalist_full_name = get_post_meta($post_id, '_journalist_full_name');
	if ($journalist_full_name == null) { $journalist_full_name[0] = true; }
		
	$description = get_post_meta($post_id, '_description');
	if ($description == null) { $description[0] = true; }
	
	$tags = get_post_meta($post_id, '_tags');
	if ($tags == null) { $tags[0] = true; }
	
	$link_format = get_post_meta($post_id, '_link_format');
	
	$display_list = get_post_meta($post_id, '_display_list');
	if ($display_list == null) { $display_list[0] = false; }
	
	$embed_video = get_post_meta($post_id, '_embed_video');
	if ($embed_video == null) { $embed_video[0] = false; }
	
	$video_width = get_post_meta($post_id, '_video_width');
	if ($video_width == null) { $video_width[0] = 425; }
	
	?>

	<fieldset id="publish2-div">
		<div>

		<p><label for="publish2-link_page" style="line-height:20px;display:block;">Display links from Publish2&nbsp;&nbsp;&nbsp;
		<select name="publish2-link_page">
			<option value="1" <?php if ($link_page[0] == true ) { echo 'selected="selected"'; }?>>On</option>
			<option value="0" <?php if ($link_page[0] == false ) { echo 'selected="selected"'; }?>>Off</option>
			</select>
		</label></p>
		
		<p><label for="publish2-feedlink" style="padding-bottom:5px;">Source URL for links (required):<br / >
			<input type="text" id="publish2-feedlink" name="publish2-feedlink" size="60" value="<?php echo $feedlink[0]; ?>"/><?php if (p2_check_url($feedlink[0]) == false) echo '&nbsp;&nbsp;&nbsp;<span style="color:red;"><a href="http://wordpress.org/extend/plugins/publish2/faq/" style="color:red;" title="What does this mean?">Bad URL</a>.</span>'; ?>
		</label></p>

		<p><label for="publish2-link_count" style="padding-bottom:5px;line-height:20px;display:block;">Number of links to display:&nbsp;&nbsp;&nbsp;
			<input type="text" id="publish2-link_count" name="publish2-link_count" value="<?php echo $link_count[0]; ?>"/>
		</label></p>
		
		<p><label for="publish-advanced_options" style="padding-bottom:5px;line-height:20px;display:block;">Select link elements to display:&nbsp;&nbsp;
			<select name="publish2-advanced_options" onchange="return p2_display_options(this)">
				<option value="0" <?php if ($advanced_options[0] == false) { echo 'selected="selected"'; }?>>Basic Options</option>
				<option value="1" <?php if ($advanced_options[0] == true) { echo 'selected="selected"'; }?>>Advanced Options</option>
			</select>
		</label></p>
		
		<div class="normal_options" <?php if ($advanced_options[0] == true) { echo 'style="display:none;"'; }?>>
		
		<p><label for="publish2-publication_name" style="padding-bottom:5px;line-height:20px;display:block;">
			<input type="checkbox" id="publish2-publication_name" name="publish2-publication_name" <?php if ($publication_name[0] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Publication name
		</label></p>
			
		<p><label for="publish2-publication_date" style="padding-bottom:5px;line-height:20px;display:block;">
			<input type="checkbox" id="publish2-publication_date" name="publish2-publication_date" <?php if ($publication_date[0] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Publication date
		</label></p>
			
		<p><label for="publish2-journalist_full_name" style="padding-bottom:5px;line-height:20px;display:block;">
			<input type="checkbox" id="publish2-journalist_full_name" name="publish2-journalist_full_name" <?php if ($journalist_full_name[0] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Journalist name
		</label></p>

		<p><label for="publish2-description" style="padding-bottom:5px;line-height:20px;display:block;">
			<input type="checkbox" id="publish2-description" name="publish2-description" <?php if ($description[0] == true) echo ' checked="checked" '; ?> />&nbsp;&nbsp;&nbsp;Comment
		</label></p>
			
		<p><label for="publish2-tags" style="padding-bottom:5px;line-height:20px;display:block;">
			<input type="checkbox" id="publish2-tags" name="publish2-tags" <?php if ($tags[0] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Tags
		</label></p>

		</div>
		
		<div class="advanced_options" <?php if ($advanced_options[0] == false) { echo 'style="display:none;"'; }?>>
		
		<p><label for="publish2-link_format" style="padding-bottom:5px;line-height:20px;">
			<textarea cols="60" rows="6" id="publish2-link_format" name="publish2-link_format"><?php echo $link_format[0]; ?></textarea>
			<br />Accepts <a href="/wp-content/plugins/publish2/img/screenshots/example-tokens_page.jpg" target="_blank">tokens</a> %headline%, %source%, %date%, %journalist%, %comment%, %tags% and basic HTML. Optionally, if you save links to videos, %video% will determine the placement.
		</label></p>
		
		</div>
		
		<p style="padding-bottom:5px;line-height:20px;display:block;"><span class="normal_options" <?php if ($advanced_options[0] == true) { echo 'style="display:none;"'; }?>><input type="checkbox" id="publish2-embed_video" name="publish2-embed_video" <?php if ($embed_video[0] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Embed video (if applicable).</span> Video width: <input type="text" id="publish2-video_width" name="publish2-video_width" value="<?php echo $video_width[0]; ?>" maxlength="3" />&nbsp;pixels</p>

		<input type="hidden" name="publish2-nonce" id="publish2-nonce" value="<?php echo wp_create_nonce('publish2-nonce'); ?>" />
		
		</div>	
	</fieldset>

<?php }

// WordPress function that places a settings box at the bottom of an edit page
function p2_save_page_meta_box($post_id) {
        
	if ( !wp_verify_nonce( $_POST['publish2-nonce'], 'publish2-nonce')) {
		return $post_id;  
	}
        
	if ( 'page' == $_POST['post_type'] ) {	
		if ( !current_user_can( 'edit_page', $post_id ))  
			return $post_id;  
	}

	// Get the variables and save them to WordPress' custom fields
	$link_page = $_POST['publish2-link_page'];
	update_post_meta($post_id, '_link_page', $link_page);
	
	$feedlink = $_POST['publish2-feedlink'];
	$feedlink = p2_clean_url($feedlink);
	update_post_meta($post_id, '_feedlink', $feedlink);
	
	$link_count = $_POST['publish2-link_count'];
	if ($link_count < 1) { $link_count = 1; }
	if ($link_count > 100) { $link_count = 100; }
	update_post_meta($post_id, '_link_count', $link_count);
	
	$advanced_options = $_POST['publish2-advanced_options'];
	update_post_meta($post_id, '_advanced_options', $advanced_options);
	
	$link_format = stripslashes(strip_tags($_POST['publish2-link_format'], '<h1><h2><h3><h4><h5><h6><b><i><strong><em><span><a><p><ul><ol><li><br>'));
	update_post_meta($post_id, '_link_format', $link_format);
	
	$publication_name = $_POST['publish2-publication_name'];
	update_post_meta($post_id, '_publication_name', $publication_name);
	
	$publication_date = $_POST['publish2-publication_date'];
	update_post_meta($post_id, '_publication_date', $publication_date);
	
	$journalist_full_name = $_POST['publish2-journalist_full_name'];
	update_post_meta($post_id, '_journalist_full_name', $journalist_full_name);
	
	$description = $_POST['publish2-description'];
	update_post_meta($post_id, '_description', $description);
	
	$tags = $_POST['publish2-tags'];
	update_post_meta($post_id, '_tags', $tags);
	
	$display_list = $_POST['publish2-display_list'];
	update_post_meta($post_id, '_display_list', $display_list);
	
	$embed_video = $_POST['publish2-embed_video'];
	update_post_meta($post_id, '_embed_video', $embed_video);
	
	$video_width = $_POST['publish2-video_width'];
	if ($video_width == '') { $video_width = 425; }
	update_post_meta($post_id, '_video_width', $video_width);
	
}


// WordPress hook to add the settings box to the page edit
function p2_add_page_meta_box() {
	if (function_exists('add_meta_box')) {
		add_meta_box('publish2_settings', 'Publish2 Settings', 'p2_page_meta_box', 'page', 'normal', 'high');
	} 
}

//Publish2 WordPress hook to append the links at the bottom of a page content
function p2_page_links($content) {
	global $post;
	$post_id = $post->ID;
	
	$link_page = get_post_meta($post_id, '_link_page');
		$link_page = $link_page[0];
	$feedlink = get_post_meta($post_id, '_feedlink');
		$feedlink = $feedlink[0];
	$link_count = get_post_meta($post_id, '_link_count');
		$link_count = $link_count[0];
	$link_format = get_post_meta($post_id, '_link_format');
		$link_format = $link_format[0];
		
	$advanced_options = get_post_meta($post_id, '_advanced_options');
		$advanced_options = $advanced_options[0];
	
	$publication_name = get_post_meta($post_id, '_publication_name');
		$publication_name = $publication_name[0];
	$publication_date = get_post_meta($post_id, '_publication_date');
		$publication_date = $publication_date[0];
	$journalist_full_name = get_post_meta($post_id, '_journalist_full_name');
		$journalist_full_name = $journalist_full_name[0];
	$description = get_post_meta($post_id, '_description');
		$description = $description[0];
	$tags = get_post_meta($post_id, '_tags');
		$tags = $tags[0];
		
	$display_list = get_post_meta($post_id, '_display_list');
		$display_list = $display_list[0];
		
	$embed_video = get_post_meta($post_id, '_embed_video');
		$embed_video = $embed_video[0];
	$video_width = get_post_meta($post_id, '_video_width');
		$video_width = $video_width[0];

	// If video embedding is set to off, then set the width to zero so we can use that as marker for later
	if ($embed_video != 'on' && $advanced_options == false) {
		$video_width = 0;
	}
	
	if ($advanced_options == false) {
		$link_format = null;
	} else if ($advanced_options == true && $link_format == "") {
		$link_format = null;
		$publication_name = true;
		$publication_date = true;
		$journalist_full_name = true;
		$description = true;
		$tags = true;
	}
	
	if ($link_page == true) {
	 	$content = $content . '<div id="publish2-links_page">' . publish2($feedlink, $link_count, $publication_name, $publication_date, $journalist_full_name, $description, $tags, $link_format, 'page', $display_list, $video_width) . '</div>';
		return $content;
	} else {
		return $content;
	}

}

// Publish2 function that looks at the_content to see if there is <!--publish2--> in it. If so, display links
function p2_call_the_links($content) {
	
	$options = get_option('pubish2_settings');
	
	if(false === strpos($content, '<!--publish2-->')) {
		return $content;
	} else {
		$content .= str_replace('<!--publish2-->', publish2( $options['feedlink'], $options['link_count'], $options['publication_name'], $options['publication_date'], $options['journalist_full_name'], $options['description'], $options['tags'], $options['link_format'], 'filter'), $content );
		return $content;
	}
	
}

// WordPress function that gets called at the plugins_loaded action. Includes all of the functions to ensure that they get called at the right time
function widget_publish2_init() {
	
	// Check for the required API functions
	if ( !('register_sidebar_widget') || !function_exists('register_widget_control') ) { return; }

	// WordPress function that displays the widget configuration panel and saves options
	function widget_publish2_control() {
		
		$widget_options = $newoptions = get_option('publish2_widget_settings');
		$defaults = get_option('publish2_settings');
		
		if ($_POST['publish2-submit']) {
			$newoptions['feedlink'] = $_POST['publish2-feedlink'];
			$newoptions['widget_title'] = strip_tags(stripslashes($_POST['publish2-widget_title']));
			$newoptions['link_count'] = (int) $_POST['publish2-link_count'];
			$newoptions['advanced_options'] = $_POST['publish2-advanced_options'];
			$newoptions['link_format'] = stripslashes(strip_tags($_POST['publish2-link_format'], '<h1><h2><h3><h4><h5><h6><b><i><strong><em><span><a><p><ul><ol><li><br>'));
			$newoptions['display_list'] = (bool) $_POST['publish2-display_list'];
			$newoptions['publication_name'] = (bool) $_POST['publish2-publication_name'];
			$newoptions['publication_date'] = (bool) $_POST['publish2-publication_date'];
			$newoptions['journalist_full_name'] = (bool) $_POST['publish2-journalist_full_name'];
			$newoptions['description'] = (bool) $_POST['publish2-description'];
			$newoptions['tags'] = (bool) $_POST['publish2-tags'];
			$newoptions['embed_video'] = (bool) $_POST['publish2-embed_video'];
			$newoptions['video_width'] = (int) $_POST['publish2-video_width'];
			$newoptions['read_more_text'] = stripslashes($_POST['publish2-read_more_text']);
			$newoptions['read_more_url'] = $_POST['publish2-read_more_url'];
		}
		if ($widget_options != $newoptions) {
			$widget_options = $newoptions;
			$widget_options['feedlink'] = p2_clean_url($widget_options['feedlink']);
			update_option('publish2_widget_settings', $widget_options);
		}
		
		//@todo: If the widget hasn't been used before, then set the defaults from settings.php
		if (!isset($widget_options)) {
			//$widget_options = get_option('publish2_settings');
			//$widget_options['display_list'] = true;
		}
		if ($widget_options['read_more_text'] == null) {
			//$widget_options['read_more_text'] = "View more Links";
		}
		if ($widget_options['video_width'] == null) {
			$widget_options['video_width'] = 180;
		}

		$check_environment = p2_check_environment();
	?>
	
	<?php if ($check_environment['json'] == false) { ?>
		<div style="margin:10px auto; border:3px #f00 solid; background-color:#fdd; color:#000; padding:10px; text-align:center;">
		JSON is required for the Publish2 plugin to work. You may need to upgrade to PHP 5.
		</div>
	<?php } else if ($check_environment['file_get_contents'] == false && $check_environment['curl'] == false) {?>	
		<div style="margin:10px auto; border:3px #f00 solid; background-color:#fdd; color:#000; padding:10px; text-align:center;">
		Either file_get_contents() or cURL are required for the Publish2 plugin to work.
		</div>
	<?php } else {?>
	
		<p>Title (optional):<br />
			<input type="text" id="publish2-widget_title" size="25" name="publish2-widget_title" value="<?php echo wp_specialchars($widget_options['widget_title'], true); ?>" /></p>
		
		<p>Source URL for links (required):<br />
			<input type="text" id="publish2-feedlink" name="publish2-feedlink" value="<?php echo wp_specialchars($widget_options['feedlink'], true); ?>" size="25" /></p>
		
		<?php if (p2_check_url($widget_options['feedlink']) == false) echo '<p style="color:red;"><a href="http://wordpress.org/extend/plugins/publish2/faq/" style="color:red;" title="What does this mean?">Bad URL</a>.</p>'; ?>
			
		<p><label for="publish2-link_count">Number of links to display:&nbsp;&nbsp;&nbsp;
			<select name="publish2-link_count">
				<option <?php if ($widget_options['link_count'] == 1) { echo 'selected="selected"'; }?>>1</option>
				<option <?php if ($widget_options['link_count'] == 2) { echo 'selected="selected"'; }?>>2</option>
				<option <?php if ($widget_options['link_count'] == 3) { echo 'selected="selected"'; }?>>3</option>
				<option <?php if ($widget_options['link_count'] == 4) { echo 'selected="selected"'; }?>>4</option>
				<option <?php if ($widget_options['link_count'] == 5) { echo 'selected="selected"'; }?>>5</option>
				<option <?php if ($widget_options['link_count'] == 6) { echo 'selected="selected"'; }?>>6</option>
				<option <?php if ($widget_options['link_count'] == 7) { echo 'selected="selected"'; }?>>7</option>
				<option <?php if ($widget_options['link_count'] == 8) { echo 'selected="selected"'; }?>>8</option>
				<option <?php if ($widget_options['link_count'] == 9) { echo 'selected="selected"'; }?>>9</option>
				<option <?php if ($widget_options['link_count'] == 10) { echo 'selected="selected"'; }?>>10</option>
				<option <?php if ($widget_options['link_count'] == 15) { echo 'selected="selected"'; }?>>15</option>
				<option <?php if ($widget_options['link_count'] == 20) { echo 'selected="selected"'; }?>>20</option>
				<option <?php if ($widget_options['link_count'] == 25) { echo 'selected="selected"'; }?>>25</option>
			</select>
		</label></p>
		
		<p>Basic display options:</p>
		
		<p><input type="checkbox" id="publish2-publication_name" name="publish2-publication_name" <?php if ($widget_options['publication_name'] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Publication name</p>
			
		<p><input type="checkbox" id="publish2-publication_date" name="publish2-publication_date" <?php if ($widget_options['publication_date'] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Publication date</p>
			
		<p><input type="checkbox" id="publish2-journalist_full_name" name="publish2-journalist_full_name" <?php if ($widget_options['journalist_full_name'] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Journalist name</p>

		<p><label for="publish2-description">
			<input type="checkbox" id="publish2-description" name="publish2-description" <?php if ($widget_options['description'] == true) echo ' checked="checked" '; ?> />&nbsp;&nbsp;&nbsp;Comment
		</label></p>
			
		<p><input type="checkbox" id="publish2-tags" name="publish2-tags" <?php if ($widget_options['tags'] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Tags</p>
		
		<p><input type="checkbox" id="publish2-embed_video" name="publish2-embed_video" <?php if ($widget_options['embed_video'] == true) echo ' checked="checked" '; ?>/>&nbsp;&nbsp;&nbsp;Embed video (if applicable)</p>
		
		<p>Video width:&nbsp;&nbsp;&nbsp;<input type="text" id="publish2-video_width" maxlength="3" size="5" name="publish2-video_width" value="<?php echo $widget_options['video_width']; ?>" />&nbsp;pixels</p>
		
		<p>Advanced display options:</p>
			
		<p><textarea id="publish2-link_format" name="publish2-link_format" rows="6" cols="20"><?php echo $widget_options['link_format']; ?></textarea>
			<br />Accepts <a href="/wp-content/plugins/publish2/img/screenshots/example-tokens_sidebar.jpg" target="_blank">tokens</a> %headline% %source% %date% %journalist% %comment% %tags% and basic HTML. Optionally, if you save links to videos, %video% will determine the placement. Using tokens will override the checkboxes in "Basic display options."
		</p>
		
		<p><input name="publish2-read_more_text" type="text" id="publish2-read_more_text" value="<?php echo wp_specialchars($widget_options['read_more_text'], true); ?>" size="25" /></p>
			
		<p>Alternate URL for footer text (optional):<br />
			<input name="publish2-read_more_url" type="text" id="publish2-read_more_url" value="<?php echo wp_specialchars($widget_options['read_more_url'], true); ?>" size="25" /></p>

		<input type="hidden" name="publish2-submit" id="publish2-submit" value="1" />

		<?php } 

	}

	// WordPress function that prints the widget in the sidebar
	function widget_publish2($args) {
		extract($args);
			
		$widget_options = get_option('publish2_widget_settings');
		
		if ($widget_options['link_format'] == null || $widget_options['link_format'] == '') {
			$widget_options['display_list'] = true;
			$widget_options['link_format'] = null;
			if ($widget_options['embed_video'] != true) { $widget_options['video_width'] = 0; }
			
		} else if ($widget_options['link_format'] != null && $widget_options['link_format'] != '') {
			$widget_options['display_list'] = false;
			if ($widget_options['video_width'] == '') { $widget_options['video_width'] = 180; }
		}
		
		// If the user has added text as a title, add it to the top of the widget
		echo $before_widget . $before_title;
		if ($widget_options['widget_title'] != "") {
			echo '<span class="publish2_header">' . $widget_options['widget_title'] . '</span>';
		}
		echo $after_title;

		publish2($widget_options['feedlink'], $widget_options['link_count'], $widget_options['publication_name'], $widget_options['publication_date'], $widget_options['journalist_full_name'], $widget_options['description'], $widget_options['tags'], $widget_options['link_format'], 'widget', $widget_options['display_list'], $widget_options['video_width']);
			
		if ( $widget_options['read_more_text'] != "" ) {
			echo '<p><a href="';
			if ( $widget_options['read_more_url'] != "" ) {
				echo $widget_options['read_more_url'];
			} else {
				echo $widget_options['feedlink'];
			}
			echo '" class="publish2_footer">' . $widget_options['read_more_text'] . '</a></p>';
		}
		echo $after_widget;

	}

	// Tells the Dynamic Sidebar about our new widget and its control
	$widget_ops = array('classname' => 'widget_publish2', 'description' => __( 'Display links from Publish2' ) );
	wp_register_sidebar_widget('publish2', __('Publish2'), 'widget_publish2', $widget_ops);
	wp_register_widget_control('publish2', __('Publish2'), 'widget_publish2_control', 400, 200 );

}

// WordPress function to create a Publish2 Settings page in the admin
function publish2_menu() {
	add_options_page('Publish2 Settings', 'Publish2', 8, __FILE__, 'publish2_options');
}

// WordPress function that creates a Publish2 Settings page in the admin
function publish2_options() {
	
	$message = null;
	$message_updated = __("Your settings have been updated.", 'publish2');
	$options = $newoptions = get_option('publish2_settings');
	if ( $_POST['publish2-submit'] ) {
		$message = $message_updated;	
		$newoptions['feedlink'] = $_POST['publish2-feedlink'];
		$newoptions['link_format'] = stripslashes(strip_tags($_POST['publish2-link_format'], '<h1><h2><h3><h4><h5><h6><b><i><strong><em><span><a><p><ul><ol><li><br>'));
		$newoptions['widget_title'] = strip_tags(stripslashes($_POST['publish2-widget_title']));
		$newoptions['display_list'] = (bool) $_POST['publish2-display_list'];
		$newoptions['link_count'] = (int) $_POST['publish2-link_count'];
		$newoptions['publication_name'] = (bool) $_POST['publish2-publication_name'];
		$newoptions['publication_date'] = (bool) $_POST['publish2-publication_date'];
		$newoptions['journalist_full_name'] = (bool) $_POST['publish2-journalist_full_name'];
		$newoptions['description'] = (bool) $_POST['publish2-description'];
		$newoptions['tags'] = (bool) $_POST['publish2-tags'];
		$newoptions['advanced_options'] = (int) $_POST['publish2-advanced_options'];
		$newoptions['embed_video'] = (bool) $_POST['publish2-embed_video'];
		$newoptions['video_width'] = (int) $_POST['publish2-video_width'];
	}
		
	if ( $options != $newoptions ) {
		$options = $newoptions;
		if ($options['link_count'] < 1) { $options['link_count'] = 1; }	
		if ($options['link_count'] > 100) { $options['link_count'] = 100; }
		$options['feedlink'] = p2_clean_url($options['feedlink']);
		$options['newsettings'] = true;
		update_option('publish2_settings', $options);
	}
	$check_environment = p2_check_environment();
	
	if ($options['video_width'] == '') { $options['video_width'] = 180; }
	
	?>
		
	<?php if ($message) : ?>
	<div id="message" class="updated fade"><p><?php echo $message; ?></p></div>
	<?php endif; ?>
	<div id="dropmessage" class="updated" style="display:none;"></div>
		
	<div class="wrap">

		<h2>Publish2 Settings</h2>

		<?php if ($check_environment['json'] == false) { ?>
		<div style="margin:10px auto; border:3px #f00 solid; background-color:#fdd; color:#000; padding:10px; text-align:center;">JSON is required for the Publish2 plugin to work. <a href="http://wordpress.org/extend/plugins/publish2/faq/" title="What does this mean?">You may need to upgrade to at least PHP 5.2</a></div>
		<?php } else if ($check_environment['file_get_contents'] == false && $check_environment['curl'] == false) {?><div style="margin:10px auto; border:3px #f00 solid; background-color:#fdd; color:#000; padding:10px; text-align:center;"><a href="http://wordpress.org/extend/plugins/publish2/faq/" title="What does this mean?">Either file_get_contents() or cURL are required</a> for the Publish2 plugin to work.</div>
		<?php } else { ?>

		<form method="post">
			
		<img src="/wp-content/plugins/publish2/img/publish2_h350.jpg" width="350px" height="150px" style="float:right; border:1px solid #000; margin-left:10px; margin-right:10px; margin-bottom:20px;" id="p2-gallery" />

		<p onmouseover="jQuery('#p2-gallery').attr('src', '/wp-content/plugins/publish2/img/publish2_h350.jpg');"><strong>The Publish2 plugin brings link journalism and <a href="http://blog.publish2.com/2009/07/27/social-journalism-curate-the-real-time-web/" target="_blank">social journalism</a> to WordPress.</strong> Easily add links, tweets, and videos from Publish2 to your WordPress blog.</p>
		
		<p onmouseover="jQuery('#p2-gallery').attr('src', '/wp-content/plugins/publish2/img/linkassist_h350.jpg');"><a href="/wp-admin/profile.php">Enable Link Assist</a> to access your links, tweets, and videos saved on Publish2 while you're writing a post. Add links, tweets, and videos to a blog post as inline text links or displayed as a list. Insert tweets into your posts, or embed videos from YouTube or Vimeo. Filter links by tags, journalist, content type, newsgroup, or browse the newswire to find what you need.</p>
			
		<p onmouseover="jQuery('#p2-gallery').attr('src', '/wp-content/plugins/publish2/img/whatwerereading_h350.jpg');">The Publish2 plugin also displays your links, tweets, and videos in a <a href="<?php bloginfo('url'); ?>/wp-admin/widgets.php" title="Install the Widget">sidebar widget</a>, a list of links on <a href="<?php bloginfo('url'); ?>/wp-admin/edit-pages.php">any page</a>, or by using <code>&#60;&#63;php publish2(); &#63;&#62;</code> in any of your WordPress templates.</p>
				
		<h3>PHP Function Configuration</h3>
		
		<p>If you want to add links, tweets, and videos from Publish2 to a WordPress template, you can use the plugin's <code>&#60;&#63;php publish2(); &#63;&#62;</code> PHP function. The options below establish the default settings for <code>&#60;&#63;php publish2(); &#63;&#62;</code>:</p>

		<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
			<tr valign="top">
				<th scope="row">Source URL for links (required):</th>
				<td><input name="publish2-feedlink" type="text" id="publish2-feedlink" value="<?php echo wp_specialchars($options['feedlink'], true); ?>" size="50" /><?php if (p2_check_url($options['feedlink']) == false) echo '&nbsp;&nbsp;&nbsp;<span style="color:red;"><a href="http://wordpress.org/extend/plugins/publish2/faq/" style="color:red;" title="What does this mean?">Bad URL</a>.</span>'; ?><br />
				<span class="setting-description">Add a URL from My Links, a Newsgroup, or the Newswire.<br />Supports "social" URLs to include tweets and videos.</span>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row">Number of items to display:</th>
				<td><input type="text" maxlength="3" id="publish2-link_count" name="publish2-link_count" value="<?php echo wp_specialchars($options['link_count'], true); ?>"/><br />
				<span class="setting-description">Anything between 1 and 100</span>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row">Select elements to display:</th>
				<td><select name="publish2-advanced_options" onchange="return p2_display_options(this);">
					<option value="0" <?php if ($options['advanced_options'] == false) { echo 'selected="selected"'; }?>>Basic Options</option>
					<option value="1" <?php if ($options['advanced_options'] == true) { echo 'selected="selected"'; }?>>Advanced Options</option>
				</select></td>
			</tr>
		</table>
			
			<div class="normal_options" <?php if ($options['advanced_options'] == false) { echo 'style="display:block;"'; } else { echo 'style="display:none;"'; }?>>
				
			<table class="form-table" cellspacing="2" cellpadding="5" width="100%">			
				<tr valign="top">
					<th scope="row">Publication name</th>
					<td><input type="checkbox" id="publish2-publication_name" name="publish2-publication_name" <?php if ($options['publication_name'] == true) echo ' checked="checked" '; ?>/></td>
				</tr>	
				<tr valign="top">
					<th scope="row">Publication date</th>
					<td><input type="checkbox" id="publish2-publication_date" name="publish2-publication_date" <?php if ($options['publication_date'] == true) echo ' checked="checked" '; ?>/></td>
				</tr>
				<tr valign="top">
					<th scope="row">Journalist name</th>
					<td><input type="checkbox" id="publish2-journalist_full_name" name="publish2-journalist_full_name" <?php if ($options['journalist_full_name'] == true) echo ' checked="checked" '; ?>/></td>
				</tr>
				<tr valign="top">
					<th scope="row">Comment</th>
					<td><input type="checkbox" id="publish2-description" name="publish2-description" <?php if ($options['description'] == true) echo ' checked="checked" '; ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row">Tags</th>
					<td><input type="checkbox" id="publish2-tags" name="publish2-tags" <?php if ($options['tags'] == true) echo ' checked="checked" '; ?>/></td>
				</tr>
				<tr valign="top">
					<th scope="row">Embed video (if applicable)</th>
					<td><input type="checkbox" id="publish2-embed_video" name="publish2-embed_video" <?php if ($options['embed_video'] == true) echo ' checked="checked" '; ?>/></td>
				</tr>
			</table>
			
			</div>
			
			<div class="advanced_options" <?php if ($options['advanced_options'] == true) { echo 'style="display:block;"'; } else { echo 'style="display:none;"'; }?>>
			
			<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
				<tr valign="top">
					<th scope="row">You can use a combination of tokens (e.g. %headline%) and HTML to customize how each link is formatted. The field will also accept classes and IDs if you want specific styles.</th>
					<td><textarea id="publish2-link_format" name="publish2-link_format" rows="6" cols="60"><?php echo $options['link_format']; ?></textarea>
						<p style="margin-top: 10px;" class="setting-description">Accepts <a href="/wp-content/plugins/publish2/img/screenshots/example-tokens_settings.jpg" target="_blank">tokens</a> %headline%, %source%, %date%, %journalist%, %comment%, %tags% and basic HTML. Optionally, if you save links to videos, %video% will determine the placement.</p>	
					</td>
				</tr>
			</table>
			
			</div>
			
			<table class="form-table" cellspacing="2" cellpadding="5" width="100%">
				<tr valign="top">
					<th scope="row">Video width</th>
					<td><input type="text" maxlength="3" id="publish2-video_width" name="publish2-video_width" value="<?php echo $options['video_width']; ?>"/>&nbsp;<span class="setting-description">pixels</span></td>
				</tr>
				
				<tr valign="top">
					<th scope="row">Add bullets (unordered list)&nbsp;&nbsp;</th>
					<td><input type="checkbox" id="publish2-display_list" name="publish2-display_list" <?php if ($options['display_list'] == true) echo ' checked="checked" '; ?>/>
					</td>
				</tr>
			</table>
			
			<div class="submit">
				<input type="submit" name="publish2-submit" id="publish2-submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
			</div>
			
			<h3>More PHP Function Options</h3>
			
			<p>If you want to customize <code>&#60;&#63;php publish2(); &#63;&#62;</code> to display different links in different locations on your WordPress Theme, the function accepts these parameters:</p>
			
			<p><code>&#60;&#63;php publish2($feedlink[str], $link_count[int], $headline[bool], $date[bool], $journalist[bool], $comment[bool], $tags[bool], $link_format[str]); &#63;&#62;</code></p>
			
			<h3>CSS Styling for Basic Display</h3>
			<p>If you're using the basic checkbox options to select which link elements to display, the plugin renders HTML with unique CSS classes to define how your links are displayed. Here is sample HTML to use as a guide:</p>
			
			<p><code>&lt;h4&gt;&lt;span&gt;What I'm Reading&lt;/span&gt;&lt;/h4&gt;<br />
				&lt;h4&gt;&lt;a href="http://newssite.com/article"&gt;Sample Headline&lt;/a&gt;&lt;/h4&gt;<br />
				&lt;p&gt;&lt;span&gt;newssite.com&lt;/span&gt; | &lt;span&gt;July 13, 2009&lt;/span&gt;&lt;/p&gt;<br />
				&lt;p&gt;&lt;a href="http://www.publish2.com/journalists/daniel-bachhuber"&gt;Daniel Bachhuber&lt;/a&gt; says: &lt;span&gt;This is an insightful article, highly recommended.&lt;/span&gt;&lt;/p&gt;<br />
				&lt;p&gt;Tags: &lt;a href="http://www.publish2.com/journalists/daniel-bachhuber/tag1"&gt;Tag1&lt;/a&gt;, &lt;a href="http://www. publish2.com/journalists/daniel-bachhuber/tag2"&gt;Tag2&lt;/a&gt;<br />
				&lt;p&gt;&lt;a href="http://www.publish2.com/journalists/daniel-bachhuber/links"&gt;More of Daniel's Links&lt;/a&gt;&lt;/p&gt;<br />
			</code></p>
			
		</form>
			
	</div>

	<?php }
		
}

// WordPress hook to add a P2 settings box at the end of a user's profile
function p2_profile_options() {

	// Get the user's information so that we can pull their P2 settings from the database
	global $profileuser;
	$user_id = (int) $profileuser->ID;
	$defaults = get_option('publish2_widget_settings');
	$feedlink = get_usermeta($user_id, 'publish2_url');
	$linkassist = get_usermeta($user_id, 'publish2_linkassist');
	$linkassist_publication = get_usermeta($user_id, 'p2_linkassist_publication');
	$linkassist_date = get_usermeta($user_id, 'p2_linkassist_date');
	$linkassist_journalist = get_usermeta($user_id, 'p2_linkassist_journalist');
	$linkassist_comment = get_usermeta($user_id, 'p2_linkassist_comment');
	$linkassist_tags = get_usermeta($user_id, 'p2_linkassist_tags');
	$video_width = get_usermeta($user_id, 'p2_video_width');
	
	// Check to see whether the settings have been used before. If not, fill in with the defaults
	if ($linkassist == null) { $linkassist = 'on'; }
	if ($feedlink == null) { $feedlink = $defaults['feedlink']; }
	if ($linkassist_publication == null) { $linkassist_publication = $defaults['publication_name']; }
	if ($linkassist_date == null) { $linkassist_date = $defaults['publication_date']; }
	if ($linkassist_journalist == null) { $linkassist_journalist = $defaults['journalist_full_name']; }
	if ($linkassist_comment == null) { $linkassist_comment = $defaults['description']; }
	if ($linkassist_tags == null) { $linkassist_tags = $defaults['tags']; }
	if ($video_width == null) { $video_width = 425; }
	
	?>
	
	<h3>Publish2 Link Assist Settings</h3>
	
	<table class="form-table">
		<tr>
			<th>Enable Link Assist</th>
			<td><input type="checkbox" id="publish2-linkassist" name="publish2-linkassist" <?php if ($linkassist == 'on') echo 'checked="checked"'; ?> /></td>
		</tr>
		<tr>
			<th>Publish2 links URL to use for Link Assist</th>
			<td><input type="text" id="publish2-feedlink" class="regular-text" name="publish2-feedlink" value="<?php echo $feedlink; ?>"/></td>
		</tr>
		<tr>
			<th>Details to add with Link Assist</th>
			<td>
				<input type="checkbox" id="p2-linkassist_publication" name="p2-linkassist_publication" <?php if ($linkassist_publication == 'on') echo 'checked="checked"'; ?> />&nbsp;&nbsp;Publication name<br />
				<input type="checkbox" id="p2-linkassist_date" name="p2-linkassist_date" <?php if ($linkassist_date == 'on') echo 'checked="checked"'; ?> />&nbsp;&nbsp;Publication date<br />
				<input type="checkbox" id="p2-linkassist_journalist" name="p2-linkassist_journalist" <?php if ($linkassist_journalist == 'on') echo 'checked="checked"'; ?> />&nbsp;&nbsp;Journalist name<br />
				<input type="checkbox" id="p2-linkassist_comment" name="p2-linkassist_comment" <?php if ($linkassist_comment == 'on') echo 'checked="checked"'; ?> />&nbsp;&nbsp;Comment<br />
				<input type="checkbox" id="p2-linkassist_tags" name="p2-linkassist_tags" <?php if ($linkassist_tags == 'on') echo 'checked="checked"'; ?> />&nbsp;&nbsp;Tags<br />
			</td>
		</tr>
		<tr>
			<th>Video embed width</th>
			<td>
				<input type="text" maxlength="3" id="p2-video_width" name="p2-video_width" value="<?php echo $video_width; ?>"/>&nbsp;&nbsp;&nbsp;<span class="setting-description">pixels</span>
			</td>
	</table>
	
	<?php
	
}

// WordPress hook that runs when someone updates their profile options. Grabs the information in the P2 fields and saves it to the metadata fields associated with the user
function p2_save_profile_options($user_id) {
	
	$linkassist = $_POST['publish2-linkassist'];
	if ($linkassist != 'on') { $linkassist = 'off'; }
	update_usermeta($user_id, 'publish2_linkassist', $linkassist);
	
	$feedlink = $_POST['publish2-feedlink'];
	$feedlink = p2_clean_url($feedlink);	
	update_usermeta($user_id, 'publish2_url', $feedlink);
	
	$linkassist_publication = $_POST['p2-linkassist_publication'];
	if ($linkassist_publication != 'on') { $linkassist_publication = 'off'; }
	update_usermeta($user_id, 'p2_linkassist_publication', $linkassist_publication);
	
	$linkassist_date = $_POST['p2-linkassist_date'];
	if ($linkassist_date != 'on') { $linkassist_date = 'off'; }
	update_usermeta($user_id, 'p2_linkassist_date', $linkassist_date);
	
	$linkassist_journalist = $_POST['p2-linkassist_journalist'];
	if ($linkassist_journalist != 'on') { $linkassist_journalist = 'off'; }
	update_usermeta($user_id, 'p2_linkassist_journalist', $linkassist_journalist);
	
	$linkassist_comment = $_POST['p2-linkassist_comment'];
	if ($linkassist_comment != 'on') { $linkassist_comment = 'off'; }
	update_usermeta($user_id, 'p2_linkassist_comment', $linkassist_comment);
	
	$linkassist_tags = $_POST['p2-linkassist_tags'];
	if ($linkassist_tags != 'on') { $linkassist_tags = 'off'; }
	update_usermeta($user_id, 'p2_linkassist_tags', $linkassist_tags);
	
	$video_width = $_POST['p2-video_width'];
	update_usermeta($user_id, 'p2_video_width', $video_width);
	
}

// Scripts and CSS files to include in the admin header
add_action('admin_print_scripts', 'publish2_js_admin_header');

// Link Assist actions to run when editing or saving a user's profile
add_action('edit_user_profile', 'p2_profile_options');
add_action('show_user_profile', 'p2_profile_options');
add_action('profile_update', 'p2_save_profile_options');

// Add the Link Assist box, if applicable, to the edit post screen. Also, save link if changed
add_action('admin_menu', 'p2_add_post_linkassist_box');
add_action('save_post', 'p2_save_post_meta_box');
add_action('edit_post', 'p2_save_post_meta_box');
add_action('publish_post', 'p2_save_post_meta_box');

// Includes a whole number of WordPress actions to make sure that the functions get hooked into the instance
add_action('widgets_init', 'widget_publish2_init');

// Used to append a P2 Links meta box at the end of a page
add_action('save_post', 'p2_save_page_meta_box');
add_action('edit_post', 'p2_save_page_meta_box');
add_action('publish_post', 'p2_save_page_meta_box');
add_action('edit_page_form', 'p2_save_page_meta_box');
add_action('admin_menu', 'p2_add_page_meta_box');

add_action('the_content', 'p2_page_links');
add_filter('the_content', 'p2_call_the_links', 10);

add_action('admin_menu', 'publish2_menu');

?>